@@ -6,7 +6,7 @@ from django.contrib.contenttypes.models import ContentType
 from actstream.exceptions import check_actionable_model
 
 
-def follow(user, obj, send_action=True, actor_only=False):
+def follow(user, obj, send_action=True, actor_only=True):
     """
     Creates a relationship allowing the object's activities to appear in the
     user's stream.
