@@ -1,7 +1,6 @@
 from datetime import datetime
 
 from django.db import models
-from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext as _
 
@@ -9,11 +8,11 @@ from django.contrib.contenttypes import generic
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.auth.models import User
 
-from actstream import managers
-from actstream.settings import MODELS, MANAGER_MODULE
+from actstream import managers, settings as actstream_settings
 from actstream.signals import action
 from actstream.actions import action_handler
 
+
 class Follow(models.Model):
     """
     Lets a user follow the activities of any specific actor
@@ -22,15 +21,16 @@ class Follow(models.Model):
 
     content_type = models.ForeignKey(ContentType)
     object_id = models.CharField(max_length=255)
-    actor = generic.GenericForeignKey()
-
+    follow_object = generic.GenericForeignKey()
+    actor_only = models.BooleanField("Only follow actions where the object is "
+        "the target.", default=True)
     objects = managers.FollowManager()
 
     class Meta:
         unique_together = ('user', 'content_type', 'object_id')
 
     def __unicode__(self):
-        return u'%s -> %s' % (self.user, self.actor)
+        return u'%s -> %s' % (self.user, self.follow_object)
 
 
 class Action(models.Model):
@@ -86,7 +86,7 @@ class Action(models.Model):
 
     public = models.BooleanField(default=True)
 
-    objects = MANAGER_MODULE()
+    objects = actstream_settings.MANAGER_MODULE()
 
     class Meta:
         ordering = ('-timestamp', )
@@ -148,22 +148,28 @@ target_stream = Action.objects.target
 user_stream = Action.objects.user
 model_stream = Action.objects.model_actions
 
-# setup GenericRelations for actionable models
-for model in MODELS.values():
-    if not model:
-        continue
-    opts = model._meta
-    for field in ('actor', 'target', 'action_object'):
-        generic.GenericRelation(Action,
-            content_type_field='%s_content_type' % field,
-            object_id_field='%s_object_id' % field,
-            related_name='actions_with_%s_%s_as_%s' % (
-                model._meta.app_label, model._meta.module_name, field),
-        ).contribute_to_class(model, '%s_actions' % field)
 
-        # @@@ I'm not entirely sure why this works
-        setattr(Action, 'actions_with_%s_%s_as_%s' % (model._meta.app_label,
-            model._meta.module_name, field), None)
+def setup_generic_relations():
+    """
+    Set up GenericRelations for actionable models.
+    """
+    for model in actstream_settings.MODELS.values():
+        if not model:
+            continue
+        for field in ('actor', 'target', 'action_object'):
+            generic.GenericRelation(Action,
+                content_type_field='%s_content_type' % field,
+                object_id_field='%s_object_id' % field,
+                related_name='actions_with_%s_%s_as_%s' % (
+                    model._meta.app_label, model._meta.module_name, field),
+            ).contribute_to_class(model, '%s_actions' % field)
+
+            # @@@ I'm not entirely sure why this works
+            setattr(Action, 'actions_with_%s_%s_as_%s' % (
+                model._meta.app_label, model._meta.module_name, field), None)
+
+
+setup_generic_relations()
 
 # connect the signal
-action.connect(action_handler, dispatch_uid='actstream.models')
\ No newline at end of file
+action.connect(action_handler, dispatch_uid='actstream.models')
